@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -69,7 +69,7 @@ class CControllerPopupItemTestSend extends CControllerPopupItemTest {
 			'key'					=> 'string',
 			'interface'				=> 'array',
 			'ipmi_sensor'			=> 'string',
-			'item_type'				=> 'in '.implode(',', [ITEM_TYPE_ZABBIX, ITEM_TYPE_TRAPPER, ITEM_TYPE_SIMPLE, ITEM_TYPE_INTERNAL, ITEM_TYPE_ZABBIX_ACTIVE, ITEM_TYPE_AGGREGATE, ITEM_TYPE_HTTPTEST, ITEM_TYPE_EXTERNAL, ITEM_TYPE_DB_MONITOR, ITEM_TYPE_IPMI, ITEM_TYPE_SSH, ITEM_TYPE_TELNET, ITEM_TYPE_CALCULATED, ITEM_TYPE_JMX, ITEM_TYPE_SNMPTRAP, ITEM_TYPE_DEPENDENT, ITEM_TYPE_HTTPAGENT, ITEM_TYPE_SNMP, ITEM_TYPE_SCRIPT]),
+			'item_type'				=> 'in '.implode(',', [ITEM_TYPE_ZABBIX, ITEM_TYPE_TRAPPER, ITEM_TYPE_SIMPLE, ITEM_TYPE_INTERNAL, ITEM_TYPE_ZABBIX_ACTIVE, ITEM_TYPE_HTTPTEST, ITEM_TYPE_EXTERNAL, ITEM_TYPE_DB_MONITOR, ITEM_TYPE_IPMI, ITEM_TYPE_SSH, ITEM_TYPE_TELNET, ITEM_TYPE_CALCULATED, ITEM_TYPE_JMX, ITEM_TYPE_SNMPTRAP, ITEM_TYPE_DEPENDENT, ITEM_TYPE_HTTPAGENT, ITEM_TYPE_SNMP, ITEM_TYPE_SCRIPT]),
 			'jmx_endpoint'			=> 'string',
 			'macros'				=> 'array',
 			'output_format'			=> 'in '.implode(',', [HTTPCHECK_STORE_RAW, HTTPCHECK_STORE_JSON]),
@@ -102,9 +102,10 @@ class CControllerPopupItemTestSend extends CControllerPopupItemTest {
 			'url'					=> 'string',
 			'value'					=> 'string',
 			'value_type'			=> 'in '.implode(',', [ITEM_VALUE_TYPE_UINT64, ITEM_VALUE_TYPE_FLOAT, ITEM_VALUE_TYPE_STR, ITEM_VALUE_TYPE_LOG, ITEM_VALUE_TYPE_TEXT]),
-			'valuemapid'			=> 'int32',
+			'valuemapid'			=> 'id',
 			'verify_host'			=> 'in 0,1',
-			'verify_peer'			=> 'in 0,1'
+			'verify_peer'			=> 'in 0,1',
+			'not_supported'			=> 'in 1'
 		];
 
 		$ret = $this->validateInput($fields);
@@ -228,7 +229,8 @@ class CControllerPopupItemTestSend extends CControllerPopupItemTest {
 		$preproc_test_data = [
 			'value' => $this->getInput('value', ''),
 			'steps' => $this->getInput('steps', []),
-			'single' => !$this->show_final_result
+			'single' => !$this->show_final_result,
+			'state' => 0
 		];
 
 		// Get previous value and time.
@@ -251,10 +253,18 @@ class CControllerPopupItemTestSend extends CControllerPopupItemTest {
 			]
 		];
 
+		$valuemap = ($this->getInput('valuemapid', 0) != 0)
+			? API::ValueMap()->get([
+				'output' => [],
+				'selectMappings' => ['type', 'newvalue', 'value'],
+				'valuemapids' => $this->getInput('valuemapid')
+			])[0]
+			: [];
+
 		// Get value from host.
 		if ($this->get_value_from_host) {
 			// Get post data for particular item type.
-			$item_test_data = $this->getItemTestProperties($this->getInputAll());
+			$item_test_data = $this->getItemTestProperties($this->getInputAll(), true);
 
 			// Apply effective macros values to properties.
 			$item_test_data = $this->resolveItemPropertyMacros($item_test_data);
@@ -283,10 +293,22 @@ class CControllerPopupItemTestSend extends CControllerPopupItemTest {
 				$item_test_data['parameters'] = $this->transformParametersFields($item_test_data['parameters']);
 			}
 
+			if ($item_test_data['type'] == ITEM_TYPE_CALCULATED) {
+				$item_test_data['host']['hostid'] = $this->getInput('hostid');
+			}
+
 			// Only non-empty fields need to be sent to server.
 			$item_test_data = $this->unsetEmptyValues($item_test_data);
 
-			if ($this->item_type != ITEM_TYPE_AGGREGATE && $this->item_type != ITEM_TYPE_CALCULATED) {
+			/*
+			 * Server will turn off status code check if field value is empty. If field is not present, then server will
+			 * default to check if status code is 200.
+			 */
+			if ($this->item_type == ITEM_TYPE_HTTPAGENT && !array_key_exists('status_codes', $item_test_data)) {
+				$item_test_data['status_codes'] = '';
+			}
+
+			if ($this->item_type != ITEM_TYPE_CALCULATED) {
 				unset($item_test_data['value_type']);
 			}
 
@@ -319,7 +341,13 @@ class CControllerPopupItemTestSend extends CControllerPopupItemTest {
 				}
 
 				if (array_key_exists('error', $result) && $result['error'] !== '') {
-					error($result['error']);
+					if ($preproc_test_data['steps']
+							&& $preproc_test_data['steps'][0]['type'] == ZBX_PREPROC_VALIDATE_NOT_SUPPORTED) {
+						$preproc_test_data['state'] = 1;
+					}
+					else {
+						error($result['error']);
+					}
 				}
 			}
 
@@ -327,6 +355,9 @@ class CControllerPopupItemTestSend extends CControllerPopupItemTest {
 				$output['messages'] = $messages->toString();
 			}
 		}
+		else {
+			$preproc_test_data['state'] = $this->getInput('not_supported', 0);
+		}
 
 		// Test preprocessing steps.
 		$this->eol = parent::getInput('eol', ZBX_EOL_LF);
@@ -350,12 +381,6 @@ class CControllerPopupItemTestSend extends CControllerPopupItemTest {
 				$test_failed = false;
 				$test_outcome = null;
 
-				$step_types = array_column($preproc_test_data['steps'], 'type');
-				$insert_index = array_search(ZBX_PREPROC_VALIDATE_NOT_SUPPORTED, $step_types);
-				if ($insert_index !== false) {
-					array_splice($result['steps'], $insert_index, 0, [['result' => ' ']]);
-				}
-
 				foreach ($preproc_test_data['steps'] as $i => &$step) {
 					if ($test_failed) {
 						// If test is failed, proceesing steps are skipped from results.
@@ -372,6 +397,9 @@ class CControllerPopupItemTestSend extends CControllerPopupItemTest {
 								$test_failed = true;
 							}
 						}
+						elseif ($step['type'] == ZBX_PREPROC_VALIDATE_NOT_SUPPORTED) {
+							$step['result'] = $preproc_test_data['value'];
+						}
 					}
 
 					unset($step['type'], $step['params'], $step['error_handler'], $step['error_handler_params']);
@@ -393,11 +421,10 @@ class CControllerPopupItemTestSend extends CControllerPopupItemTest {
 							'result' => $result['result']
 						];
 
-						if ($this->getInput('valuemapid', 0)) {
-							$mapped_value = getMappedValue($result['result'], $this->getInput('valuemapid'));
-							if ($mapped_value !== false) {
-								$output['mapped_value'] = $mapped_value;
-							}
+						if ($valuemap) {
+							$output['mapped_value'] = CValueMapHelper::applyValueMap($preproc_test_data['value_type'],
+								$result['result'], $valuemap
+							);
 						}
 					}
 					elseif (array_key_exists('error', $result)) {
