@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -39,7 +39,7 @@ class CControllerWidgetPlainTextView extends CControllerWidget {
 		$fields = $this->getForm()->getFieldsData();
 		$error = null;
 
-		$dynamic_widget_name = $this->getDefaultHeader();
+		$dynamic_widget_name = $this->getDefaultName();
 		$same_host = true;
 		$items = [];
 		$histories = [];
@@ -56,6 +56,7 @@ class CControllerWidgetPlainTextView extends CControllerWidget {
 				$items = API::Item()->get([
 					'output' => ['itemid', 'hostid', 'name', 'key_', 'value_type', 'units', 'valuemapid'],
 					'selectHosts' => ['name'],
+					'selectValueMap' => ['mappings'],
 					'itemids' => $fields['itemids'],
 					'webitems' => true,
 					'preservekeys' => true
@@ -72,6 +73,7 @@ class CControllerWidgetPlainTextView extends CControllerWidget {
 					$items = API::Item()->get([
 						'output' => ['itemid', 'hostid', 'name', 'key_', 'value_type', 'units', 'valuemapid'],
 						'selectHosts' => ['name'],
+						'selectValueMap' => ['mappings'],
 						'filter' => [
 							'hostid' => $dynamic_hostid,
 							'key_' => array_keys($keys)
