@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -19,6 +19,10 @@
 **/
 
 
+/**
+ * @var CView $this
+ */
+
 if ($data['uncheck']) {
 	uncheckTableRows('script');
 }
@@ -39,6 +43,14 @@ $widget = (new CWidget())
 				(new CTextBox('filter_name', $data['filter']['name']))
 					->setWidth(ZBX_TEXTAREA_FILTER_SMALL_WIDTH)
 					->setAttribute('autofocus', 'autofocus')
+			),
+			(new CFormList())->addRow(_('Scope'),
+				(new CRadioButtonList('filter_scope', (int) $data['filter']['scope']))
+					->addValue(_('Any'), -1)
+					->addValue(_('Action operation'), ZBX_SCRIPT_SCOPE_ACTION)
+					->addValue(_('Manual host action'), ZBX_SCRIPT_SCOPE_HOST)
+					->addValue(_('Manual event action'), ZBX_SCRIPT_SCOPE_EVENT)
+					->setModern(true)
 			)
 		])
 		->addVar('action', 'script.list')
@@ -48,45 +60,115 @@ $scriptsForm = (new CForm())
 	->setName('scriptsForm')
 	->setId('scripts');
 
+$url = (new CUrl('zabbix.php'))
+	->setArgument('action', 'script.list')
+	->getUrl();
+
 $scriptsTable = (new CTableInfo())
 	->setHeader([
 		(new CColHeader(
-			(new CCheckBox('all_scripts'))->onClick("checkAll('".$scriptsForm->getName()."', 'all_scripts', 'scriptids');")
+			(new CCheckBox('all_scripts'))
+				->onClick("checkAll('".$scriptsForm->getName()."', 'all_scripts', 'scriptids');")
 		))->addClass(ZBX_STYLE_CELL_WIDTH),
-		make_sorting_header(_('Name'), 'name', $data['sort'], $data['sortorder']),
+		make_sorting_header(_('Name'), 'name', $data['sort'], $data['sortorder'], $url),
+		_('Scope'),
+		_('Used in actions'),
 		_('Type'),
 		_('Execute on'),
-		make_sorting_header(_('Commands'), 'command', $data['sort'], $data['sortorder']),
+		make_sorting_header(_('Commands'), 'command', $data['sort'], $data['sortorder'], $url),
 		_('User group'),
 		_('Host group'),
 		_('Host access')
 	]);
 
 foreach ($data['scripts'] as $script) {
+	$actions = [];
+
+	switch ($script['scope']) {
+		case ZBX_SCRIPT_SCOPE_ACTION:
+			$scope = _('Action operation');
+
+			if ($script['actions']) {
+				$i = 0;
+
+				foreach ($script['actions'] as $action) {
+					$i++;
+
+					if ($i > $data['config']['max_in_table']) {
+						$actions[] = ' &hellip;';
+
+						break;
+					}
+
+					if ($actions) {
+						$actions[] = ', ';
+					}
+
+					if (CWebUser::checkAccess(CRoleHelper::UI_CONFIGURATION_ACTIONS)) {
+						$url = (new CUrl('actionconf.php'))
+							->setArgument('form', 'update')
+							->setArgument('actionid', $action['actionid']);
+
+						$actions[] = (new CLink($action['name'], $url))
+							->addClass(ZBX_STYLE_LINK_ALT)
+							->addClass(ZBX_STYLE_GREY);
+					}
+					else {
+						$actions[] = (new CSpan($action['name']))
+							->addClass(ZBX_STYLE_GREY);
+					}
+				}
+			}
+			break;
+
+		case ZBX_SCRIPT_SCOPE_HOST:
+			$scope = _('Manual host action');
+			break;
+
+		case ZBX_SCRIPT_SCOPE_EVENT:
+			$scope = _('Manual event action');
+			break;
+	}
+
 	switch ($script['type']) {
 		case ZBX_SCRIPT_TYPE_CUSTOM_SCRIPT:
-			$scriptType = _('Script');
+			$type = _('Script');
 			break;
+
 		case ZBX_SCRIPT_TYPE_IPMI:
-			$scriptType = _('IPMI');
+			$type = _('IPMI');
+			break;
+
+		case ZBX_SCRIPT_TYPE_SSH:
+			$type = _('SSH');
+			break;
+
+		case ZBX_SCRIPT_TYPE_TELNET:
+			$type = _('Telnet');
+			break;
+
+		case ZBX_SCRIPT_TYPE_WEBHOOK:
+			$type = _('Webhook');
 			break;
 	}
 
 	if ($script['type'] == ZBX_SCRIPT_TYPE_CUSTOM_SCRIPT) {
 		switch ($script['execute_on']) {
 			case ZBX_SCRIPT_EXECUTE_ON_AGENT:
-				$scriptExecuteOn = _('Agent');
+				$execute_on = _('Agent');
 				break;
+
 			case ZBX_SCRIPT_EXECUTE_ON_SERVER:
-				$scriptExecuteOn = _('Server');
+				$execute_on = _('Server');
 				break;
+
 			case ZBX_SCRIPT_EXECUTE_ON_PROXY:
-				$scriptExecuteOn = _('Server (proxy)');
+				$execute_on = _('Server (proxy)');
 				break;
 		}
 	}
 	else {
-		$scriptExecuteOn = '';
+		$execute_on = '';
 	}
 
 	$scriptsTable->addRow([
@@ -94,8 +176,10 @@ foreach ($data['scripts'] as $script) {
 		(new CCol(
 			new CLink($script['name'], 'zabbix.php?action=script.edit&scriptid='.$script['scriptid'])
 		))->addClass(ZBX_STYLE_NOWRAP),
-		$scriptType,
-		$scriptExecuteOn,
+		$scope,
+		$actions,
+		$type,
+		$execute_on,
 		(new CCol(
 			zbx_nl2br(htmlspecialchars($script['command'], ENT_COMPAT, 'UTF-8'))
 		))->addClass(ZBX_STYLE_MONOSPACE_FONT),
@@ -115,4 +199,6 @@ $scriptsForm->addItem([
 ]);
 
 // append form to widget
-$widget->addItem($scriptsForm)->show();
+$widget
+	->addItem($scriptsForm)
+	->show();
