@@ -407,7 +407,7 @@ function saveItemTestInputs() {
 			interfaceid: <?= $data['interfaceid'] ?> || 0,
 			address: jQuery('#interface_address', $form).val(),
 			port: jQuery('#interface_port', $form).val(),
-			interface_details: interface ? interface['details'] : null
+			interface_details: (interface && 'details' in interface) ? interface['details'] : null
 		});
 	<?php endif ?>
 
@@ -446,7 +446,6 @@ jQuery(document).ready(function($) {
 		placeholder: <?= json_encode(_('value')) ?>,
 		value: <?= json_encode($data['value']) ?>,
 		monospace_font: false,
-		maxlength: 65535,
 		autofocus: true,
 		readonly: false,
 		grow: 'auto',
@@ -457,7 +456,6 @@ jQuery(document).ready(function($) {
 		placeholder: <?= $data['show_prev'] ? json_encode(_('value')) : '""' ?>,
 		value: <?= json_encode($data['prev_value']) ?>,
 		monospace_font: false,
-		maxlength: 65535,
 		disabled: <?= $data['show_prev'] ? 'false' : 'true' ?>,
 		grow: 'auto',
 		rows: 0
