@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -215,6 +215,7 @@ class CDService extends CApiService {
 
 		// select_drules
 		if ($options['selectDRules'] !== null && $options['selectDRules'] != API_OUTPUT_COUNT) {
+			$drules = [];
 			$relationMap = new CRelationMap();
 			// discovered items
 			$dbRules = DBselect(
@@ -227,14 +228,19 @@ class CDService extends CApiService {
 				$relationMap->addRelation($rule['dserviceid'], $rule['druleid']);
 			}
 
-			$drules = API::DRule()->get([
-				'output' => $options['selectDRules'],
-				'druleids' => $relationMap->getRelatedIds(),
-				'preservekeys' => true
-			]);
-			if (!is_null($options['limitSelects'])) {
-				order_result($drules, 'name');
+			$related_ids = $relationMap->getRelatedIds();
+
+			if ($related_ids) {
+				$drules = API::DRule()->get([
+					'output' => $options['selectDRules'],
+					'druleids' => $related_ids,
+					'preservekeys' => true
+				]);
+				if (!is_null($options['limitSelects'])) {
+					order_result($drules, 'name');
+				}
 			}
+
 			$result = $relationMap->mapMany($result, $drules, 'drules');
 		}
 
