@@ -91,58 +91,54 @@ class CXmlExportWriter extends CExportWriter {
 	 */
 	private function mapName($name) {
 		$map = [
-			'groups' => 'group',
-			'templates' => 'template',
-			'hosts' => 'host',
-			'interfaces' => 'interface',
-			'applications' => 'application',
-			'items' => 'item',
-			'discovery_rules' => 'discovery_rule',
 			'conditions' => 'condition',
-			'item_prototypes' => 'item_prototype',
-			'application_prototypes' => 'application_prototype',
-			'trigger_prototypes' => 'trigger_prototype',
+			'dashboards' => 'dashboard',
+			'dependencies' => 'dependency',
+			'discovery_rules' => 'discovery_rule',
+			'elements' => 'element',
+			'fields' => 'field',
+			'graph_items' => 'graph_item',
 			'graph_prototypes' => 'graph_prototype',
-			'host_prototypes' => 'host_prototype',
+			'graphs' => 'graph',
 			'group_links' => 'group_link',
 			'group_prototypes' => 'group_prototype',
-			'triggers' => 'trigger',
-			'dependencies' => 'dependency',
-			'screen_items' => 'screen_item',
-			'macros' => 'macro',
-			'screens' => 'screen',
+			'groups' => 'group',
+			'headers' => 'header',
+			'host_prototypes' => 'host_prototype',
+			'hosts' => 'host',
+			'httptests' => 'httptest',
 			'images' => 'image',
-			'graphs' => 'graph',
-			'graph_items' => 'graph_item',
-			'maps' => 'map',
-			'urls' => 'url',
-			'selements' => 'selement',
-			'elements' => 'element',
+			'interfaces' => 'interface',
+			'item_prototypes' => 'item_prototype',
+			'items' => 'item',
+			'lines' => 'line',
 			'links' => 'link',
 			'linktriggers' => 'linktrigger',
-			'value_maps' => 'value_map',
+			'lld_macro_paths' => 'lld_macro_path',
+			'macros' => 'macro',
 			'mappings' => 'mapping',
-			'httptests' => 'httptest',
-			'steps' => 'step',
-			'tags' => 'tag',
-			'preprocessing' => 'step',
-			'headers' => 'header',
-			'variables' => 'variable',
-			'query_fields' => 'query_field',
+			'maps' => 'map',
+			'media_types' => 'media_type',
+			'message_templates' => 'message_template',
+			'operations' => 'operation',
+			'overrides' => 'override',
+			'pages' => 'page',
 			'parameters' => 'parameter',
 			'posts' => 'post_field',
+			'preprocessing' => 'step',
+			'query_fields' => 'query_field',
+			'selements' => 'selement',
 			'shapes' => 'shape',
-			'lines' => 'line',
-			'lld_macro_paths' => 'lld_macro_path',
+			'steps' => 'step',
+			'tags' => 'tag',
+			'templates' => 'template',
 			'tls_accept' => 'option',
-			'media_types' => 'media_type',
-			'parameters' => 'parameter',
-			'message_templates' => 'message_template',
-			'overrides' => 'override',
-			'operations' => 'operation',
-			'dashboards' => 'dashboard',
-			'widgets' => 'widget',
-			'fields' => 'field'
+			'trigger_prototypes' => 'trigger_prototype',
+			'triggers' => 'trigger',
+			'urls' => 'url',
+			'valuemaps' => 'valuemap',
+			'variables' => 'variable',
+			'widgets' => 'widget'
 		];
 
 		return isset($map[$name]) ? $map[$name] : false;
