@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -26,11 +26,16 @@ class CImportConverterFactory extends CRegistryFactory {
 
 	public function __construct() {
 		parent::__construct([
-			'1.0' => new C10ImportConverter(),
-			'2.0' => new C20ImportConverter(),
-			'3.0' => new C30ImportConverter(),
-			'3.2' => new C32ImportConverter(),
-			'3.4' => new C34ImportConverter()
+			'1.0' => 'C10ImportConverter',
+			'2.0' => 'C20ImportConverter',
+			'3.0' => 'C30ImportConverter',
+			'3.2' => 'C32ImportConverter',
+			'3.4' => 'C34ImportConverter',
+			'4.0' => 'C40ImportConverter',
+			'4.2' => 'C42ImportConverter',
+			'4.4' => 'C44ImportConverter',
+			'5.0' => 'C50ImportConverter',
+			'5.2' => 'C52ImportConverter'
 		]);
 	}
 }
