@@ -217,7 +217,7 @@ class CHelpItems {
 					'description' => _('CPU utilisation percentage. Returns float')
 				],
 				[
-					'key' => 'system.hostname[<type>]',
+					'key' => 'system.hostname[<type>,<transform>]',
 					'description' => _('System host name. Returns string')
 				],
 				[
@@ -571,7 +571,7 @@ class CHelpItems {
 					'description' => _('CPU utilisation percentage. Returns float')
 				],
 				[
-					'key' => 'system.hostname[<type>]',
+					'key' => 'system.hostname[<type>,<transform>]',
 					'description' => _('System host name. Returns string')
 				],
 				[
@@ -896,6 +896,10 @@ class CHelpItems {
 					'key' => 'vmware.hv.hw.vendor[<url>,<uuid>]',
 					'description' => _('VMware hypervisor vendor name, <url> - VMware service URL, <uuid> - VMware hypervisor host name')
 				],
+				[
+					'key' => ' vmware.hv.maintenance[<url>,<uuid>]',
+					'description' => _('VMware hypervisor maintenance status, <url> - VMware service URL, <uuid> - VMware hypervisor host name')
+				],
 				[
 					'key' => 'vmware.hv.memory.size.ballooned[<url>,<uuid>]',
 					'description' => _('VMware hypervisor ballooned memory size, <url> - VMware service URL, <uuid> - VMware hypervisor host name')
@@ -920,6 +924,10 @@ class CHelpItems {
 					'key' => 'vmware.hv.power[<url>,<uuid>,<max>]',
 					'description' => _('Power usage , <url> - VMware service URL, <uuid> - VMware hypervisor host name, <max> - Maximum allowed power usage')
 				],
+				[
+					'key' => 'vmware.hv.sensors.get[<url>,<uuid>]',
+					'description' => _('VMware hypervisor HW vendor state sensors, <url> - VMware service URL, <uuid> - VMware hypervisor host name. Returns JSON')
+				],
 				[
 					'key' => 'vmware.hv.sensor.health.state[<url>,<uuid>]',
 					'description' => _('VMware hypervisor health state rollup sensor, <url> - VMware service URL, <uuid> - VMware hypervisor host name. Returns 0 - gray; 1 - green; 2 - yellow; 3 - red')
