@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -24,8 +24,8 @@
  */
 class CWidgetFormProblems extends CWidgetForm {
 
-	public function __construct($data) {
-		parent::__construct($data, WIDGET_PROBLEMS);
+	public function __construct($data, $templateid) {
+		parent::__construct($data, $templateid, WIDGET_PROBLEMS);
 
 		$this->data = self::convertDottedKeys($this->data);
 
@@ -64,6 +64,7 @@ class CWidgetFormProblems extends CWidgetForm {
 
 		// Hosts field.
 		$field_hosts = new CWidgetFieldMsHost('hostids', _('Hosts'));
+		$field_hosts->filter_preselect_host_group_field = 'groupids_';
 
 		if (array_key_exists('hostids', $this->data)) {
 			$field_hosts->setValue($this->data['hostids']);
@@ -89,7 +90,7 @@ class CWidgetFormProblems extends CWidgetForm {
 
 		$this->fields[$field_severities->getName()] = $field_severities;
 
-		// Tag evalype (And/Or).
+		// Tag evaltype (And/Or).
 		$field_evaltype = (new CWidgetFieldRadioButtonList('evaltype', _('Tags'), [
 			TAG_EVAL_TYPE_AND_OR => _('And/Or'),
 			TAG_EVAL_TYPE_OR => _('Or')
@@ -195,7 +196,7 @@ class CWidgetFormProblems extends CWidgetForm {
 		];
 
 		// Sort entries by.
-		$field_sort = (new CWidgetFieldComboBox('sort_triggers', _('Sort entries by'), [
+		$field_sort = (new CWidgetFieldSelect('sort_triggers', _('Sort entries by'), [
 			SCREEN_SORT_TRIGGERS_TIME_DESC => _('Time').' ('._('descending').')',
 			SCREEN_SORT_TRIGGERS_TIME_ASC => _('Time').' ('._('ascending').')',
 			SCREEN_SORT_TRIGGERS_SEVERITY_DESC => _('Severity').' ('._('descending').')',
@@ -205,13 +206,7 @@ class CWidgetFormProblems extends CWidgetForm {
 			SCREEN_SORT_TRIGGERS_HOST_NAME_DESC => _('Host').' ('._('descending').')',
 			SCREEN_SORT_TRIGGERS_HOST_NAME_ASC => _('Host').' ('._('ascending').')'
 		]))
-			->setDefault(SCREEN_SORT_TRIGGERS_TIME_DESC)
-			->setAction(
-				'jQuery(":checkbox[name=show_timeline]")'.
-					'.filter(":disabled").prop("checked", true).end()'.
-					'.prop("disabled", !'.CJs::encodeJson($sort_with_enabled_show_timeline).'[this.value])'.
-					'.filter(":disabled").prop("checked", false)'
-			);
+			->setDefault(SCREEN_SORT_TRIGGERS_TIME_DESC);
 
 		if (array_key_exists('sort_triggers', $this->data)) {
 			$field_sort->setValue($this->data['sort_triggers']);
