@@ -1,21 +1,50 @@
+<?php
+/*
+** Zabbix
+** Copyright (C) 2001-2021 Zabbix SIA
+**
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program; if not, write to the Free Software
+** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+**/
+
+
+/**
+ * @var CView $this
+ */
+?>
+
 <script type="text/x-jquery-tmpl" id="preprocessing-steps-tmpl">
 	<?php
-	$preproc_types_cbbox = new CComboBox('preprocessing[#{rowNum}][type]', '');
+	$preproc_types_select = (new CSelect('preprocessing[#{rowNum}][type]'))
+		->setId('preprocessing_#{rowNum}_type')
+		->setValue(ZBX_PREPROC_REGSUB)
+		->setWidthAuto();
 
 	foreach (get_preprocessing_types(null, true, $data['preprocessing_types']) as $group) {
-		$cb_group = new COptGroup($group['label']);
+		$opt_group = new CSelectOptionGroup($group['label']);
 
 		foreach ($group['types'] as $type => $label) {
-			$cb_group->addItem(new CComboItem($type, $label));
+			$opt_group->addOption(new CSelectOption($type, $label));
 		}
 
-		$preproc_types_cbbox->addItem($cb_group);
+		$preproc_types_select->addOptionGroup($opt_group);
 	}
 
 	echo (new CListItem([
 		(new CDiv([
 			(new CDiv())->addClass(ZBX_STYLE_DRAG_ICON),
-			(new CDiv($preproc_types_cbbox))
+			(new CDiv($preproc_types_select))
 				->addClass('list-numbered-item')
 				->addClass('step-name'),
 			(new CDiv())->addClass('step-parameters'),
@@ -83,82 +112,6 @@
 
 <script type="text/javascript">
 	jQuery(function($) {
-		/**
-		 * Collect current preprocessing step properties.
-		 *
-		 * @param {array} step_nums  List of step numbers to collect.
-		 *
-		 * @return array
-		 */
-		function getPreprocessingSteps(step_nums) {
-			var steps = [];
-
-			step_nums.each(function(num) {
-				var type = $('[name="preprocessing[' + num + '][type]"]', $preprocessing).val(),
-					error_handler = $('[name="preprocessing[' + num + '][on_fail]"]').is(':checked')
-						? $('[name="preprocessing[' + num + '][error_handler]"]:checked').val()
-						: <?= ZBX_PREPROC_FAIL_DEFAULT ?>,
-					params = [];
-
-				var on_fail = {
-					error_handler: error_handler,
-					error_handler_params: (error_handler == <?= ZBX_PREPROC_FAIL_SET_VALUE ?>
-							|| error_handler == <?= ZBX_PREPROC_FAIL_SET_ERROR ?>)
-						? $('[name="preprocessing[' + num + '][error_handler_params]"]').val()
-						: ''
-				};
-
-				if ($('[name="preprocessing[' + num + '][params][0]"]', $preprocessing).length) {
-					params.push($('[name="preprocessing[' + num + '][params][0]"]', $preprocessing).val());
-				}
-				if ($('[name="preprocessing[' + num + '][params][1]"]', $preprocessing).length) {
-					params.push($('[name="preprocessing[' + num + '][params][1]"]', $preprocessing).val());
-				}
-				if ($('[name="preprocessing[' + num + '][params][2]"]', $preprocessing).length) {
-					// ZBX-16642
-					if (type == <?= ZBX_PREPROC_CSV_TO_JSON ?>) {
-						if ($('[name="preprocessing[' + num + '][params][2]"]', $preprocessing).is(':checked')) {
-							params.push($('[name="preprocessing[' + num + '][params][2]"]', $preprocessing).val());
-						}
-						else {
-							params.push(0);
-						}
-					}
-					else {
-						params.push($('[name="preprocessing[' + num + '][params][2]"]', $preprocessing).val());
-					}
-				}
-
-				steps.push($.extend({
-					type: type,
-					params: params.join("\n")
-				}, on_fail));
-			});
-
-			return steps;
-		}
-
-		/**
-		 * Creates preprocessing test modal window.
-		 *
-		 * @param {array}  step_nums          List of step numbers to collect.
-		 * @param {bool}   show_final_result  Either the final result should be displayed.
-		 * @param {object} trigger_elmnt      UI element triggered function.
-		 */
-		function openPreprocessingTestDialog(step_nums, show_final_result, trigger_elmnt) {
-			var $step_obj = $(trigger_elmnt).closest('.preprocessing-list-item, .preprocessing-list-foot');
-
-			PopUp('popup.preproctest.edit', $.extend({
-				delay: $('#delay').val() || '',
-				value_type: $('#value_type').val() || <?= CControllerPopupPreprocTest::ZBX_DEFAULT_VALUE_TYPE ?>,
-				steps: getPreprocessingSteps(step_nums),
-				hostid: <?= $data['hostid'] ?>,
-				test_type: <?= $data['preprocessing_test_type'] ?>,
-				step_obj: $step_obj.attr('data-step') || -1,
-				show_final_result: show_final_result ? 1 : 0
-			}, {'data': $step_obj.data('test-data') || []}), 'preprocessing-test', trigger_elmnt);
-		}
-
 		function makeParameterInput(index, type) {
 			var preproc_param_single_tmpl = new Template($('#preprocessing-steps-parameters-single-tmpl').html()),
 				preproc_param_double_tmpl = new Template($('#preprocessing-steps-parameters-double-tmpl').html()),
@@ -170,7 +123,7 @@
 				case '<?= ZBX_PREPROC_MULTIPLIER ?>':
 					return $(preproc_param_single_tmpl.evaluate({
 						rowNum: index,
-						placeholder: <?= CJs::encodeJson(_('number')) ?>
+						placeholder: <?= json_encode(_('number')) ?>
 					})).css('width', <?= ZBX_TEXTAREA_NUMERIC_BIG_WIDTH ?>);
 
 				case '<?= ZBX_PREPROC_RTRIM ?>':
@@ -178,76 +131,76 @@
 				case '<?= ZBX_PREPROC_TRIM ?>':
 					return $(preproc_param_single_tmpl.evaluate({
 						rowNum: index,
-						placeholder: <?= CJs::encodeJson(_('list of characters')) ?>
+						placeholder: <?= json_encode(_('list of characters')) ?>
 					})).css('width', <?= ZBX_TEXTAREA_SMALL_WIDTH ?>);
 
 				case '<?= ZBX_PREPROC_XPATH ?>':
 				case '<?= ZBX_PREPROC_ERROR_FIELD_XML ?>':
 					return $(preproc_param_single_tmpl.evaluate({
 						rowNum: index,
-						placeholder: <?= CJs::encodeJson(_('XPath')) ?>
+						placeholder: <?= json_encode(_('XPath')) ?>
 					}));
 
 				case '<?= ZBX_PREPROC_JSONPATH ?>':
 				case '<?= ZBX_PREPROC_ERROR_FIELD_JSON ?>':
 					return $(preproc_param_single_tmpl.evaluate({
 						rowNum: index,
-						placeholder: <?= CJs::encodeJson(_('$.path.to.node')) ?>
+						placeholder: <?= json_encode(_('$.path.to.node')) ?>
 					}));
 
 				case '<?= ZBX_PREPROC_REGSUB ?>':
 				case '<?= ZBX_PREPROC_ERROR_FIELD_REGEX ?>':
 					return $(preproc_param_double_tmpl.evaluate({
 						rowNum: index,
-						placeholder_0: <?= CJs::encodeJson(_('pattern')) ?>,
-						placeholder_1: <?= CJs::encodeJson(_('output')) ?>
+						placeholder_0: <?= json_encode(_('pattern')) ?>,
+						placeholder_1: <?= json_encode(_('output')) ?>
 					}));
 
 				case '<?= ZBX_PREPROC_VALIDATE_RANGE ?>':
 					return $(preproc_param_double_tmpl.evaluate({
 						rowNum: index,
-						placeholder_0: <?= CJs::encodeJson(_('min')) ?>,
-						placeholder_1: <?= CJs::encodeJson(_('max')) ?>
+						placeholder_0: <?= json_encode(_('min')) ?>,
+						placeholder_1: <?= json_encode(_('max')) ?>
 					}));
 
 				case '<?= ZBX_PREPROC_VALIDATE_REGEX ?>':
 				case '<?= ZBX_PREPROC_VALIDATE_NOT_REGEX ?>':
 					return $(preproc_param_single_tmpl.evaluate({
 						rowNum: index,
-						placeholder: <?= CJs::encodeJson(_('pattern')) ?>
+						placeholder: <?= json_encode(_('pattern')) ?>
 					}));
 
 				case '<?= ZBX_PREPROC_THROTTLE_TIMED_VALUE ?>':
 					return $(preproc_param_single_tmpl.evaluate({
 						rowNum: index,
-						placeholder: <?= CJs::encodeJson(_('seconds')) ?>
+						placeholder: <?= json_encode(_('seconds')) ?>
 					})).css('width', <?= ZBX_TEXTAREA_NUMERIC_BIG_WIDTH ?>);
 
 				case '<?= ZBX_PREPROC_SCRIPT ?>':
 					return $(preproc_param_multiline_tmpl.evaluate({rowNum: index})).multilineInput({
-						title: <?= CJs::encodeJson(_('JavaScript')) ?>,
-						placeholder: <?= CJs::encodeJson(_('script')) ?>,
+						title: <?= json_encode(_('JavaScript')) ?>,
+						placeholder: <?= json_encode(_('script')) ?>,
 						placeholder_textarea: 'return value',
 						label_before: 'function (value) {',
 						label_after: '}',
 						grow: 'auto',
 						rows: 0,
-						maxlength: <?= (int) $data['preprocessing_script_maxlength'] ?>
+						maxlength: <?= DB::getFieldLength('item_preproc', 'params') ?>
 					});
 
 				case '<?= ZBX_PREPROC_PROMETHEUS_PATTERN ?>':
 					return $(preproc_param_double_tmpl.evaluate({
 						rowNum: index,
-						placeholder_0: <?= CJs::encodeJson(
+						placeholder_0: <?= json_encode(
 							_('<metric name>{<label name>="<label value>", ...} == <value>')
 						) ?>,
-						placeholder_1: <?= CJs::encodeJson(_('<label name>')) ?>
+						placeholder_1: <?= json_encode(_('<label name>')) ?>
 					}));
 
 				case '<?= ZBX_PREPROC_PROMETHEUS_TO_JSON ?>':
 					return $(preproc_param_single_tmpl.evaluate({
 						rowNum: index,
-						placeholder: <?= CJs::encodeJson(
+						placeholder: <?= json_encode(
 							_('<metric name>{<label name>="<label value>", ...} == <value>')
 						) ?>
 					}));
@@ -259,25 +212,74 @@
 						width_1: <?= ZBX_TEXTAREA_NUMERIC_STANDARD_WIDTH ?>,
 						placeholder_0: ',',
 						placeholder_1: '"',
-						chkbox_label: <?= CJs::encodeJson(_('With header row')) ?>,
+						chkbox_label: <?= json_encode(_('With header row')) ?>,
 						chkbox_value: <?= ZBX_PREPROC_CSV_HEADER ?>,
 						chkbox_default: true
 					}));
 
+				case '<?= ZBX_PREPROC_STR_REPLACE ?>':
+					return $(preproc_param_double_tmpl.evaluate({
+						rowNum: index,
+						placeholder_0: <?= json_encode(_('search string')) ?>,
+						placeholder_1: <?= json_encode(_('replacement')) ?>
+					}));
+
 				default:
 					return '';
 			}
 		}
 
-		var $preprocessing = $('#preprocessing'),
-			step_index = $preprocessing.find('li.sortable').length;
+		/**
+		 * Allow only one option with value "ZBX_PREPROC_VALIDATE_NOT_SUPPORTED" to be enabled.
+		 */
+		function updateTypeOptionsAvailability() {
+			const $preproc_steps = $('z-select[name^="preprocessing["][name$="[type]"]');
+			const $preproc_steps_ns = $preproc_steps
+				.filter((_index, {value}) => value != <?= ZBX_PREPROC_VALIDATE_NOT_SUPPORTED ?>);
+
+			if ($preproc_steps_ns.length == $preproc_steps.length) {
+				for (let select of $preproc_steps_ns) {
+					for (let option of select.getOptions()) {
+						option.disabled = false;
+					}
+				}
+				return;
+			}
+
+			for (let select of $preproc_steps_ns) {
+				for (let option of select.getOptions()) {
+					if (option.value == <?= ZBX_PREPROC_VALIDATE_NOT_SUPPORTED ?>) {
+						option.disabled = true;
+					}
+				}
+			}
+		}
+
+		var $preprocessing = $('#preprocessing');
+
+		if ($preprocessing.length === 0) {
+			const prep_elem = document.querySelector('#preprocessing_div');
+
+			if (!prep_elem) {
+				return false;
+			}
+
+			let obj = prep_elem;
+			if (prep_elem.tagName === 'SPAN') {
+				obj = prep_elem.originalObject;
+			}
+
+			$preprocessing = $(obj.querySelector('#preprocessing'));
+		}
+
+		var step_index = $preprocessing.find('li.sortable').length;
 
 		$preprocessing.sortable({
 			disabled: $preprocessing.find('div.<?= ZBX_STYLE_DRAG_ICON ?>').hasClass('<?= ZBX_STYLE_DISABLED ?>'),
 			items: 'li.sortable',
 			axis: 'y',
 			containment: 'parent',
-			cursor: IE ? 'move' : 'grabbing',
+			cursor: 'grabbing',
 			handle: 'div.<?= ZBX_STYLE_DRAG_ICON ?>',
 			tolerance: 'pointer',
 			opacity: 0.6
@@ -286,8 +288,8 @@
 		$preprocessing
 			.on('click', '.element-table-add', function() {
 				var preproc_row_tmpl = new Template($('#preprocessing-steps-tmpl').html()),
-					$row = $(preproc_row_tmpl.evaluate({rowNum: step_index})),
-					type = $('select[name*="type"]', $row).val();
+					$row = $(preproc_row_tmpl.evaluate({rowNum: step_index}));
+					type = $('z-select[name*="type"]', $row).val();
 
 				$('.step-parameters', $row).html(makeParameterInput(step_index, type));
 				$(this).closest('.preprocessing-list-foot').before($row);
@@ -300,30 +302,34 @@
 					$('#preproc_test_all').show();
 					$preprocessing
 						.sortable('disable')
-						.find('div.<?= ZBX_STYLE_DRAG_ICON ?>').addClass('<?= ZBX_STYLE_DISABLED ?>');
+						.find('div.<?= ZBX_STYLE_DRAG_ICON ?>')
+						.addClass('<?= ZBX_STYLE_DISABLED ?>');
 				}
 				else if (sortable_count > 1) {
 					$preprocessing
 						.sortable('enable')
-						.find('div.<?= ZBX_STYLE_DRAG_ICON ?>').removeClass('<?= ZBX_STYLE_DISABLED ?>');
+						.find('div.<?= ZBX_STYLE_DRAG_ICON ?>')
+						.removeClass('<?= ZBX_STYLE_DISABLED ?>');
 				}
 
+				updateTypeOptionsAvailability();
 				step_index++;
 			})
 			.on('click', '#preproc_test_all', function() {
 				var step_nums = [];
-				$('select[name^="preprocessing"][name$="[type]"]', $preprocessing).each(function() {
+				$('z-select[name^="preprocessing"][name$="[type]"]', $preprocessing).each(function() {
 					var str = $(this).attr('name');
 					step_nums.push(str.substr(14, str.length - 21));
 				});
 
-				openPreprocessingTestDialog(step_nums, true, this);
+				openItemTestDialog(step_nums, true, false, this, -1);
 			})
 			.on('click', '.preprocessing-step-test', function() {
 				var str = $(this).attr('name'),
+					step_nr = $(this).attr('data-step'),
 					num = str.substr(14, str.length - 21);
 
-				openPreprocessingTestDialog([num], false, this);
+				openItemTestDialog([num], false, false, this, num);
 			})
 			.on('click', '.element-table-remove', function() {
 				$(this).closest('li.sortable').remove();
@@ -339,8 +345,10 @@
 						.sortable('disable')
 						.find('div.<?= ZBX_STYLE_DRAG_ICON ?>').addClass('<?= ZBX_STYLE_DISABLED ?>');
 				}
+
+				updateTypeOptionsAvailability();
 			})
-			.on('change', 'select[name*="type"]', function() {
+			.on('change', 'z-select[name*="type"]', function() {
 				var $row = $(this).closest('.preprocessing-list-item'),
 					type = $(this).val(),
 					$on_fail = $row.find('[name*="on_fail"]');
@@ -355,16 +363,28 @@
 					case '<?= ZBX_PREPROC_THROTTLE_VALUE ?>':
 					case '<?= ZBX_PREPROC_THROTTLE_TIMED_VALUE ?>':
 					case '<?= ZBX_PREPROC_SCRIPT ?>':
+					case '<?= ZBX_PREPROC_STR_REPLACE ?>':
 						$on_fail
 							.prop('checked', false)
 							.prop('disabled', true)
 							.trigger('change');
+						$row.find('[name*="[test]"]').prop('disabled', false);
+						break;
+
+					case '<?= ZBX_PREPROC_VALIDATE_NOT_SUPPORTED ?>':
+						$on_fail
+							.prop('checked', true)
+							.prop('disabled', true)
+							.trigger('change');
 						break;
 
 					default:
 						$on_fail.prop('disabled', false);
+						$row.find('[name*="[test]"]').prop('disabled', false);
 						break;
 				}
+
+				updateTypeOptionsAvailability();
 			})
 			.on('change', 'input[type="text"][name*="params"]', function() {
 				$(this).attr('title', $(this).val());
@@ -393,13 +413,13 @@
 				else if (error_handler == '<?= ZBX_PREPROC_FAIL_SET_VALUE ?>') {
 					$error_handler_params
 						.prop('disabled', false)
-						.attr('placeholder', <?= CJs::encodeJson(_('value')) ?>)
+						.attr('placeholder', <?= json_encode(_('value')) ?>)
 						.show();
 				}
 				else if (error_handler == '<?= ZBX_PREPROC_FAIL_SET_ERROR ?>') {
 					$error_handler_params
 						.prop('disabled', false)
-						.attr('placeholder', <?= CJs::encodeJson(_('error message')) ?>)
+						.attr('placeholder', <?= json_encode(_('error message')) ?>)
 						.show();
 				}
 			});
