@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -41,10 +41,6 @@ class CTabFilter extends CBaseComponent {
 		this.registerEvents();
 		this.initItemUnsavedState(this._active_item, this._active_item._data);
 
-		if (this._active_item instanceof CTabFilterItem) {
-			this._active_item.setFocused();
-		}
-
 		if (this._timeselector instanceof CTabFilterItem) {
 			this._timeselector._data = options.timeselector;
 			this.updateTimeselector(this._active_item, this._timeselector._data.disabled);
@@ -81,7 +77,7 @@ class CTabFilter extends CBaseComponent {
 	}
 
 	/**
-	 * Ensures item label is visible in tab filter navgation.
+	 * Ensures item label is visible in tab filter navigation.
 	 *
 	 * @param {CTabfilterItem} item    Filter item object.
 	 */
@@ -242,7 +238,7 @@ class CTabFilter extends CBaseComponent {
 	 * @return {Promise}
 	 */
 	profileUpdate(property, body) {
-		let url = new Curl('zabbix.php', false),
+		let url = new Curl('zabbix.php'),
 			signal = null;
 
 		url.setArgument('action', 'tabfilter.profile.update');
@@ -384,6 +380,11 @@ class CTabFilter extends CBaseComponent {
 				else {
 					item.fire(TABFILTERITEM_EVENT_COLLAPSE);
 				}
+
+				if (this._timeselector instanceof CTabFilterItem && item !== this._timeselector
+						&& this._timeselector._expanded) {
+					this._timeselector.removeExpanded();
+				}
 			},
 
 			expand: (ev) => {
@@ -419,7 +420,10 @@ class CTabFilter extends CBaseComponent {
 			 */
 			tabSortChanged: (ev, ui) => {
 				// Update order of this._items array.
-				var from, to, item_moved, target = ui.item[0].querySelector('[data-target] .tabfilter-item-link');
+				let from,
+					to,
+					item_moved;
+				const target = ui.item[0].querySelector('[data-target] .tabfilter-item-link');
 
 				this._items.forEach((item, index) => from = (item._target === target) ? index : from);
 				this._target.querySelectorAll('nav [data-target] .tabfilter-item-link')
@@ -444,9 +448,11 @@ class CTabFilter extends CBaseComponent {
 
 			/**
 			 * Event handler for 'Delete' button.
+			 *
+			 * @param {object} ev.detail.idx2  Index of deleted tab.
 			 */
-			deleteActiveFilterTab: (ev) => {
-				this.delete(this._active_item);
+			deleteFilterTab: (ev) => {
+				this.delete(this._items[ev.detail.idx2]);
 			},
 
 			/**
@@ -672,6 +678,21 @@ class CTabFilter extends CBaseComponent {
 		$('.ui-sortable-container', this._target).sortable({
 			items: '.tabfilter-item-label:not(:first-child)',
 			update: this._events.tabSortChanged,
+			stop: (_, ui) => {
+				const $item = ui.item;
+
+				/**
+				 * Remove inline style positon, left and top that stay after sortable.
+				 * This styles broken tabs layout.
+				 */
+				if ($item.css('position') === 'relative') {
+					$item.css({
+						'position': '',
+						'left': '',
+						'top': ''
+					});
+				}
+			},
 			axis: 'x',
 			containment: 'parent'
 		});
@@ -702,7 +723,7 @@ class CTabFilter extends CBaseComponent {
 
 		this.on('keydown', this._events.keydown);
 		this.on(TABFILTERITEM_EVENT_UPDATE, this._events.updateActiveFilterTab);
-		this.on(TABFILTERITEM_EVENT_DELETE, this._events.deleteActiveFilterTab);
+		this.on(TABFILTERITEM_EVENT_DELETE, this._events.deleteFilterTab);
 		this.on('submit', (ev) => {
 			ev.preventDefault();
 			this._filters_footer.querySelector('[name="filter_apply"]').dispatchEvent(new CustomEvent('click'));
