@@ -1,6 +1,6 @@
 /*
  ** Zabbix
- ** Copyright (C) 2001-2020 Zabbix SIA
+ ** Copyright (C) 2001-2021 Zabbix SIA
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -118,17 +118,22 @@
 						'screenitemid'
 					]
 				},
-				params_index = type_params[screen.resourcetype] ? screen.resourcetype : 'default';
-				ajax_url = new Curl('jsrpc.php'),
+				params_index = type_params[screen.resourcetype] ? screen.resourcetype : 'default',
 				self = this;
 
-			ajax_url.setArgument('type', 9); // PAGE_TYPE_TEXT
-			ajax_url.setArgument('method', 'screen.get');
-			// TODO: remove, do not use timestamp passing to server and back to ensure newest content will be shown.
-			ajax_url.setArgument('timestamp', screen.timestampActual);
+			const ajax_url = new Curl('jsrpc.php', false);
+			const post_data = {
+				type: 9, // PAGE_TYPE_TEXT
+				method: 'screen.get',
+
+				// TODO: remove, do not use timestamp passing to server and back to ensure newest content will be shown.
+				timestamp: screen.timestampActual
+			};
 
 			$.each(type_params[params_index], function (i, name) {
-				ajax_url.setArgument(name, empty(screen[name]) ? null : screen[name]);
+				if (!empty(screen[name])) {
+					post_data[name] = screen[name];
+				}
 			});
 
 			// set actual timestamp
@@ -137,8 +142,8 @@
 			// timeline params
 			// SCREEN_RESOURCE_HTTPTEST_DETAILS, SCREEN_RESOURCE_DISCOVERY, SCREEN_RESOURCE_HTTPTEST
 			if ($.inArray(screen.resourcetype, [21, 22, 23]) === -1) {
-				ajax_url.setArgument('from', screen.timeline.from);
-				ajax_url.setArgument('to', screen.timeline.to);
+				post_data.from = screen.timeline.from;
+				post_data.to = screen.timeline.to;
 			}
 
 			switch (parseInt(screen.resourcetype, 10)) {
@@ -164,16 +169,6 @@
 					self.refreshMap(id);
 					break;
 
-				// SCREEN_RESOURCE_PLAIN_TEXT
-				case 3:
-					self.refreshHtml(id, ajax_url);
-					break;
-
-				// SCREEN_RESOURCE_CLOCK
-				case 7:
-					// don't refresh anything
-					break;
-
 				// SCREEN_RESOURCE_HISTORY
 				case 17:
 					if (screen.data.action == 'showgraph') {
@@ -183,12 +178,12 @@
 						if ('itemids' in screen.data) {
 							$.each(screen.data.itemids, function (i, value) {
 								if (!empty(value)) {
-									ajax_url.setArgument('itemids[' + value + ']', value);
+									post_data['itemids[' + value + ']'] = value;
 								}
 							});
 						}
 						else {
-							ajax_url.setArgument('graphid', screen.data.graphid);
+							post_data['graphid'] = screen.data.graphid;
 						}
 
 						$.each({
@@ -198,23 +193,16 @@
 							'action': screen.data.action
 						}, function (ajax_key, value) {
 							if (!empty(value)) {
-								ajax_url.setArgument(ajax_key, value);
+								post_data[ajax_key] = value;
 							}
 						});
 
-						self.refreshHtml(id, ajax_url);
+						self.refreshHtml(id, ajax_url, post_data);
 					}
 					break;
 
-				// SCREEN_RESOURCE_LLD_SIMPLE_GRAPH
-				// SCREEN_RESOURCE_LLD_GRAPH
-				case 20:
-				case 19:
-					self.refreshProfile(id, ajax_url);
-					break;
-
 				default:
-					self.refreshHtml(id, ajax_url);
+					self.refreshHtml(id, ajax_url, post_data);
 					break;
 			}
 
@@ -249,7 +237,7 @@
 			}
 		},
 
-		refreshHtml: function(id, ajaxUrl) {
+		refreshHtml: function(id, ajaxUrl, post_data = {}) {
 			var screen = this.screens[id],
 				request_start = new CDate().getTime();
 
@@ -265,7 +253,7 @@
 					url: ajaxUrl.getUrl(),
 					type: 'post',
 					cache: false,
-					data: {},
+					data: post_data,
 					dataType: 'html',
 					success: function(html) {
 						var html = $(html);
@@ -452,38 +440,6 @@
 			return null;
 		},
 
-		refreshProfile: function(id, ajaxUrl) {
-			var screen = this.screens[id];
-
-			if (screen.isRefreshing) {
-				this.calculateReRefresh(id);
-			}
-			else {
-				screen.isRefreshing = true;
-				screen.timestampResponsiveness = new CDate().getTime();
-
-				var ajaxRequest = $.ajax({
-					url: ajaxUrl.getUrl(),
-					type: 'post',
-					data: {},
-					success: function(data) {
-						screen.timestamp = new CDate().getTime();
-						screen.isRefreshing = false;
-					},
-					error: function() {
-						window.flickerfreeScreen.calculateReRefresh(id);
-					}
-				});
-
-				$.when(ajaxRequest).always(function() {
-					if (screen.isReRefreshRequire) {
-						screen.isReRefreshRequire = false;
-						window.flickerfreeScreen.refresh(id);
-					}
-				});
-			}
-		},
-
 		calculateReRefresh: function(id) {
 			var screen = this.screens[id],
 				time = new CDate().getTime();
